@@ -1,5 +1,5 @@
 /* grep.h - interface to grep driver for searching subroutines.
-   Copyright (C) 1992, 1998, 2001, 2007, 2009-2010 Free Software Foundation,
+   Copyright (C) 1992, 1998, 2001, 2007, 2009-2022 Free Software Foundation,
    Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -17,29 +17,19 @@
    Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
    02110-1301, USA.  */
 
-#if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 6) || __STRICT_ANSI__
-# define __attribute__(x)
-#endif
+#ifndef GREP_GREP_H
+#define GREP_GREP_H 1
 
-/* Function pointer types.  */
-typedef void (*compile_fp_t) (char const *, size_t);
-typedef size_t (*execute_fp_t) (char const *, size_t, size_t *, char const *);
-
-/* grep.c expects the matchers vector to be terminated by an entry
-   with a NULL name, and to contain at least one entry. */
-extern struct matcher
-{
-  const char *name;
-  compile_fp_t compile;
-  execute_fp_t execute;
-} const matchers[];
-
-extern const char before_options[];
-extern const char after_options[];
+#include <stdbool.h>
+#include <idx.h>
 
 /* The following flags are exported from grep for the matchers
    to look at. */
-extern int match_icase;		/* -i */
-extern int match_words;		/* -w */
-extern int match_lines;		/* -x */
-extern unsigned char eolbyte;	/* -z */
+extern bool match_icase;	/* -i */
+extern bool match_words;	/* -w */
+extern bool match_lines;	/* -x */
+extern char eolbyte;		/* -z */
+
+extern char const *pattern_file_name (idx_t, idx_t *);
+
+#endif
